@@ -4,7 +4,7 @@ import pprint
 import signal
 import sys
 import warnings
-from typing import Optional
+from typing import Optional, Type, Union, Any
 
 from zope.interface.exceptions import DoesNotImplement
 
@@ -15,8 +15,9 @@ except ImportError:
     MultipleInvalid = None
 
 from zope.interface.verify import verifyClass
+from aioscrapy.logformatter import LogFormatter
 from aioscrapy import signals, Spider
-from aioscrapy.settings import overridden_settings
+from aioscrapy.settings import overridden_settings, Settings
 from aioscrapy.utils.log import (
     get_scrapy_root_handler,
     install_scrapy_root_handler,
@@ -31,7 +32,6 @@ from aioscrapy.db import db_manager
 from aioscrapy.utils.tools import async_generator_wrapper
 from aioscrapy.middleware import ExtensionManager
 from aioscrapy.core.engine import ExecutionEngine
-from aioscrapy.settings import Settings
 from aioscrapy.signalmanager import SignalManager
 from aioscrapy.utils.ossignal import install_shutdown_handlers, signal_names
 from aioscrapy.statscollectors import StatsCollector
@@ -41,7 +41,7 @@ logger = logging.getLogger(__name__)
 
 class Crawler:
 
-    def __init__(self, spidercls, settings=None):
+    def __init__(self, spidercls: Type[Spider], settings: Union[Settings, dict, None] = None) -> None:
 
         if isinstance(spidercls, Spider):
             raise ValueError('The spidercls argument must be a class, not an object')
@@ -49,7 +49,7 @@ class Crawler:
         if isinstance(settings, dict) or settings is None:
             settings = Settings(settings)
 
-        self.spidercls: Spider = spidercls
+        self.spidercls = spidercls
         self.settings = settings.copy()
         self.spidercls.update_settings(self.settings)
 
@@ -59,10 +59,10 @@ class Crawler:
         self.crawling = False
         self.spider: Optional[Spider] = None
         self.engine: Optional[ExecutionEngine] = None
-        self.extensions: Optional[ExecutionEngine] = None
-        self.logformatter: Optional[ExecutionEngine] = None
+        self.extensions: Optional[ExtensionManager] = None
+        self.logformatter: Optional[LogFormatter] = None
 
-    async def crawl(self, *args, **kwargs):
+    async def crawl(self, *args, **kwargs) -> None:
         try:
             if self.crawling:
                 raise RuntimeError("Crawling already taking place")
@@ -96,7 +96,7 @@ class Crawler:
                 await self.engine.close()
             raise e
 
-    async def stop(self):
+    async def stop(self) -> None:
         """Starts a graceful stop of the crawler and returns a deferred that is
         fired when the crawler is stopped."""
         if self.crawling:
@@ -112,7 +112,7 @@ class CrawlerRunner:
     )
 
     @staticmethod
-    def _get_spider_loader(settings):
+    def _get_spider_loader(settings: Settings) -> ISpiderLoader:
         """ Get SpiderLoader instance from settings """
         cls_path = settings.get('SPIDER_LOADER_CLASS')
         loader_cls = load_object(cls_path)
@@ -128,7 +128,7 @@ class CrawlerRunner:
             )
         return loader_cls.from_settings(settings.frozencopy())
 
-    def __init__(self, settings=None):
+    def __init__(self, settings: Union[Settings, dict, None] = None) -> None:
         if isinstance(settings, dict) or settings is None:
             settings = Settings(settings)
         self.settings = settings
@@ -144,12 +144,18 @@ class CrawlerRunner:
                       category=AioScrapyDeprecationWarning, stacklevel=2)
         return self.spider_loader
 
-    def crawl_soon(self, crawler_or_spidercls, *args, settings=None, **kwargs):
+    def crawl_soon(
+            self,
+            crawler_or_spidercls: Union[Type[Spider], Crawler],
+            *args,
+            settings: Union[Settings, dict, None] = None,
+            **kwargs
+    ) -> None:
         crawler = self.crawl(crawler_or_spidercls, settings=settings)
         self.crawlers.setdefault(crawler, (args, kwargs))
         self.active_crawler(crawler, *args, **kwargs)
 
-    def active_crawler(self, crawler, *args, **kwargs):
+    def active_crawler(self, crawler: Crawler, *args, **kwargs) -> None:
         task = asyncio.create_task(crawler.crawl(*args, **kwargs))
         self._active.add(task)
 
@@ -161,7 +167,13 @@ class CrawlerRunner:
 
         task.add_done_callback(_done)
 
-    def crawl(self, crawler_or_spidercls, *args, settings=None, **kwargs):
+    def crawl(
+            self,
+            crawler_or_spidercls: Union[Type[Spider], Crawler],
+            *args,
+            settings: Union[Settings, dict, None] = None,
+            **kwargs
+    ) -> Crawler:
         if isinstance(crawler_or_spidercls, Spider):
             raise ValueError(
                 'The crawler_or_spidercls argument cannot be a spider object, '
@@ -170,7 +182,11 @@ class CrawlerRunner:
         self.crawlers.setdefault(crawler, (args, kwargs))
         return crawler
 
-    def create_crawler(self, crawler_or_spidercls, settings):
+    def create_crawler(
+            self,
+            crawler_or_spidercls: Union[Type[Spider], Crawler, str],
+            settings: Union[Settings, dict, None]
+    ) -> Crawler:
         if isinstance(crawler_or_spidercls, Spider):
             raise ValueError(
                 'The crawler_or_spidercls argument cannot be a spider object, '
@@ -179,44 +195,52 @@ class CrawlerRunner:
             return crawler_or_spidercls
         return self._create_crawler(crawler_or_spidercls, settings)
 
-    def _create_crawler(self, spidercls, settings):
+    def _create_crawler(
+            self,
+            spidercls: Union[Type[Spider], str],
+            settings: Union[Settings, dict, None]
+    ) -> Crawler:
         if isinstance(spidercls, str):
             spidercls = self.spider_loader.load(spidercls)
         return Crawler(spidercls, settings=settings)
 
-    async def stop(self):
-        return await asyncio.gather(*[c.stop() for c in self.crawlers])
+    async def stop(self) -> None:
+        await asyncio.gather(*[c.stop() for c in self.crawlers])
 
 
 class CrawlerProcess(CrawlerRunner):
 
-    def __init__(self, settings=None, install_root_handler=True):
+    def __init__(
+            self,
+            settings: Union[Settings, dict, None] = None,
+            install_root_handler: bool = True
+    ) -> None:
         super().__init__(settings)
         install_shutdown_handlers(self._signal_shutdown)
         configure_logging(self.settings, install_root_handler)
 
-    def _signal_shutdown(self, signum, _):
+    def _signal_shutdown(self, signum: Any, _) -> None:
         install_shutdown_handlers(self._signal_kill)
         signame = signal_names[signum]
         logger.info("Received %(signame)s, shutting down gracefully. Send again to force ",
                     {'signame': signame})
         asyncio.create_task(self._graceful_stop_reactor())
 
-    def _signal_kill(self, signum, _):
+    def _signal_kill(self, signum: Any, _) -> None:
         install_shutdown_handlers(signal.SIG_IGN)
         signame = signal_names[signum]
         logger.info('Received %(signame)s twice, forcing unclean shutdown',
                     {'signame': signame})
         asyncio.create_task(self._stop_reactor())
 
-    async def run(self):
+    async def run(self) -> None:
         for crawler, (args, kwargs) in self.crawlers.items():
             self.active_crawler(crawler, *args, **kwargs)
         while self._active:
             await asyncio.gather(*self._active)
         await self.recycle_db_connect()
 
-    def start(self):
+    def start(self) -> None:
         if sys.platform.startswith('win'):
             asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
         else:
@@ -227,17 +251,17 @@ class CrawlerProcess(CrawlerRunner):
                 pass
         asyncio.run(self.run())
 
-    async def _graceful_stop_reactor(self):
+    async def _graceful_stop_reactor(self) -> None:
         await self.stop()
         await self.recycle_db_connect()
 
-    async def _stop_reactor(self):
+    async def _stop_reactor(self) -> None:
         try:
             await self.recycle_db_connect()
         finally:
             asyncio.get_event_loop().stop()
 
-    async def recycle_db_connect(self):
-        # 回收所以的链接
+    async def recycle_db_connect(self) -> None:
+        # recycle pool of db_manager
         if not len(self._active):
             await db_manager.close_all()
